@@ -26,12 +26,14 @@ Setup instance (`lndb init`, `lndb load`):
    init
    load
 
-Close a loaded instance context:
+More instance operations:
 
 .. autosummary::
    :toctree:
 
    close
+   info
+   set_storage
 
 Dev API
 -------
@@ -44,11 +46,13 @@ Dev API
    Storage
 """
 
-__version__ = "0.25.3"
+__version__ = "0.26.1"
 import atexit
 from os import name as _os_name
 
+from ._info import info
 from ._schema import schema  # noqa
+from ._set import set_storage
 from ._settings import settings  # noqa
 from ._settings_instance import InstanceSettings, Storage  # noqa
 from ._settings_user import UserSettings  # noqa
